@@ -41,8 +41,12 @@ _code_and_message_to_error_setting: Dict[str, Dict[str, MypyErrorSetting]] = {
         "error: Function is missing a type annotation": ("disallow_untyped_defs", False),
         "": ("disallow_incomplete_defs", False),
     },
-    "no-untyped-call": {"": ("disallow_untyped_calls", False),},
-    "": {"error: unused 'type: ignore' comment": _warn_unused_ignores_error_setting,},
+    "no-untyped-call": {
+        "": ("disallow_untyped_calls", False),
+    },
+    "": {
+        "error: unused 'type: ignore' comment": _warn_unused_ignores_error_setting,
+    },
 }
 _settings_that_require_other_settings: Dict[MypyErrorSetting, FrozenSet[MypyErrorSetting]] = {
     ("disallow_incomplete_defs", False): frozenset({("disallow_untyped_defs", False)})
@@ -135,7 +139,8 @@ def _get_child_module_names_for_module(module_name: str) -> Set[str]:
     module = importlib.import_module(module_name)
 
     result: Set[str] = set()
-    for module_info in pkgutil.walk_packages(module.__path__, module_name + "."):
+    module_path = module.__path__  # type: ignore  # mypy doesn't seem to be able to find this attr
+    for module_info in pkgutil.walk_packages(module_path, module_name + "."):
         result.add(module_info.name)
 
     return result
